Module: Autotest::Sound

Defined in:
lib/autotest/sound.rb

Overview

To use this autotest plugin add the following to your autotest config file (~/.autotest):

require 'autotest/sound'

Class Method Summary collapse

Class Method Details

.hook_soundsObject

Override this to specify the sounds for the hooks.

def self.hook_sounds { #:run => 'Purr', :red => 'Basso.aiff', :green => 'Blow.aiff', :quit => 'Submarine.aiff', :run_command => 'Purr.aiff', #:ran_command => 'Morse.aiff' } end



32
33
34
35
36
37
38
39
40
41
# File 'lib/autotest/sound.rb', line 32

def self.hook_sounds
  {
    #:run => sound('Purr'),
    :red => 'Basso.aiff',
    :green => 'Blow.aiff',
    :quit => 'Submarine.aiff',
    :run_command => 'Purr.aiff',
    #:ran_command => 'Morse.aiff'
  }
end

.sound_pathObject

Override this to specify an alternative path to your hook sounds.

def self.sound_path '/System/Library/Sounds' end



16
17
18
# File 'lib/autotest/sound.rb', line 16

def self.sound_path
  '/System/Library/Sounds'
end